.. PyDOAS documentation master file, created by
   sphinx-quickstart on Tue Apr 12 14:39:57 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pydoas
=================

pydoas provides high level functionality for import of text file based results from DOAS analyses (i.e. it cannot  perform the actual DOAS retrieval).
It supports default import routines for the result file format of the software DOASIS.

.. note::

  pydoas is not a library for performing DOAS spectrum analysis. An overview and assessment of existing DOAS
  retrieval codes can by found e.g. in `Peters et al., 2017 <https://amt.copernicus.org/articles/10/955/2017/amt-10-955-2017.html>`_


**Contents:**

.. toctree::
   :maxdepth: 3
   
   practicalities
   examples
   api
   remarks_doas_analysis


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
